# Credits

## Development Lead

* [Etienne Lac](https://gitlab.com/etienne.lac) (etienne.lac@safrangroup.com)
* [Duc Trung Le](https://gitlab.com/ductrungle) (duc-trung.le@safrangroup.com)

## Contributors

* [Frederic Collonval](https://gitlab.com/fcollonval)
* [Adrien Delsalle](https://gitlab.com/adriendelsalle)
* [Guy De Spiegeleer](https://gitlab.com/GuyDS) (guy.de-spiegeleer@safrangroup.com)
* Alexis Cassier (alexis.cassier@safrangroup.com)
* Amath Waly Ndiaye
* Thomas Federici (thomas.federici@safrangroup.com)
* [Jeffrey Borlik](https://gitlab.com/JeffreyBorlik)
* [Adrien Talatizi](https://gitlab.com/AdrienTalatizi)
